@@ -22,6 +22,8 @@
 #ifndef _DISTORTION_H
 #define _DISTORTION_H
 
+#include "../VoiceBoard/Synth--.h"
+
 /**
  * @brief A distortion (waveshaping) effect unit
  */
@@ -33,8 +35,7 @@ public:
 	void	SetCrunch		(float);
 	void	Process			(float *buffer, unsigned);
 private:
-	float drive, crunch;
-	int done;
+	SmoothedParam crunch;
 };
 
 #endif
