@@ -134,4 +134,61 @@ struct IIRFilterFirstOrder
 	float _a0, _a1, _b1, _z;
 };
 
+#define NONCOPYABLE( class ) \
+	private:                 \
+		class(const class&); \
+		void operator=(const class &)
+
+class ParamSmoother
+{
+	NONCOPYABLE(ParamSmoother);
+	
+public:
+	
+	ParamSmoother(): _z(0.f) {}
+	
+	inline float processSample(float x)
+	{
+		return (_z += ((x - _z) * 0.005f));
+	}
+	
+	inline void set(float z)
+	{
+		_z = z;
+	}
+	
+private:
+	
+	float _z;
+};
+
+class SmoothedParam
+{
+	NONCOPYABLE(SmoothedParam);
+	
+public:
+	
+	SmoothedParam(float rawValue = 0.f): _rawValue(rawValue) {}
+	
+	void operator=(float rawValue)
+	{
+		_rawValue = rawValue;
+	}
+	
+	float getRawValue()
+	{
+		return _rawValue;
+	}
+	
+	inline float tick()
+	{
+		return _smoother.processSample(_rawValue);
+	}
+	
+private:
+	
+	float _rawValue;
+	ParamSmoother _smoother;
+};
+
 #endif
